@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2024 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2025 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -100,9 +100,13 @@ main_add_commit(struct view *view, enum line_type type, struct commit *template,
 
 	view_column_info_update(view, line);
 
-	if ((opt_start_on_head && is_head_commit(commit->id)) ||
-	    (view->env->goto_id[0] && !strncmp(view->env->goto_id, commit->id, SIZEOF_REV - 1)))
+	if (view->env->goto_id[0] && !strncmp(view->env->goto_id, commit->id, SIZEOF_REV - 1)) {
 		select_view_line(view, line->lineno + 1);
+		view->env->goto_id[0] = 0;
+	} else if (opt_start_on_head && is_head_commit(commit->id)) {
+		select_view_line(view, line->lineno + 1);
+		opt_start_on_head = false;
+	}
 
 	return commit;
 }
@@ -133,11 +137,11 @@ main_add_changes_commit(struct view *view, enum line_type type, const char *pare
 		ids[STRING_SIZE(NULL_ID)] = 0;
 
 	if (!time_now(&now, &tz)) {
-		commit.time.tz = tz.tz_minuteswest * 60;
-		commit.time.sec = now.tv_sec - commit.time.tz;
+		commit.author_time.tz = commit.commit_time.tz = tz.tz_minuteswest * 60;
+		commit.author_time.sec = commit.commit_time.sec = now.tv_sec - commit.author_time.tz;
 	}
 
-	commit.author = &unknown_ident;
+	commit.author = commit.committer = &unknown_ident;
 	main_register_commit(view, &commit, ids, false);
 	if (state->with_graph && *parent)
 		graph->render_parents(graph, &commit.graph);
@@ -362,9 +366,14 @@ main_get_column_data(struct view *view, const struct line *line, struct view_col
 {
 	struct main_state *state = view->private;
 	struct commit *commit = line->data;
+	struct view_column *column = get_view_column(view, VIEW_COLUMN_DATE);
+	bool use_author_date = column && column->opt.date.use_author;
 
 	column_data->author = commit->author;
-	column_data->date = &commit->time;
+	column_data->committer = commit->committer;
+	column_data->date = use_author_date
+				? &commit->author_time
+				: &commit->commit_time;
 	column_data->id = commit->id;
 
 	column_data->commit_title = commit->title;
@@ -381,12 +390,12 @@ main_get_column_data(struct view *view, const struct line *line, struct view_col
 static bool
 main_add_reflog(struct view *view, struct main_state *state, char *reflog)
 {
-	char *end = strchr(reflog, ' ');
+	char *end = strchr(reflog, '}');
 	int id_width;
 
 	if (!end)
 		return false;
-	*end = 0;
+	*++end = 0;
 
 	if (!realloc_reflogs(&state->reflog, state->reflogs, 1)
 	    || !(reflog = strdup(reflog)))
@@ -462,9 +471,12 @@ main_read(struct view *view, struct buffer *buf, bool force_stop)
 		main_register_commit(view, &state->current, line, is_boundary);
 
 		if (author) {
-			char *title = io_memchr(buf, author, 0);
+			char *committer = io_memchr(buf, author, 0);
+			char *title = io_memchr(buf, committer, 0);
 
-			parse_author_line(author, &commit->author, &commit->time);
+			parse_author_line(author, &commit->author, &commit->author_time);
+			if (committer)
+				parse_author_line(committer, &commit->committer, &commit->commit_time);
 			if (state->with_graph)
 				graph->render_parents(graph, &commit->graph);
 			if (title) {
@@ -503,11 +515,16 @@ main_read(struct view *view, struct buffer *buf, bool force_stop)
 
 	case LINE_AUTHOR:
 		parse_author_line(line + STRING_SIZE("author "),
-				  &commit->author, &commit->time);
+				  &commit->author, &commit->author_time);
 		if (state->with_graph)
 			graph->render_parents(graph, &commit->graph);
 		break;
 
+	case LINE_COMMITTER:
+		parse_author_line(line + STRING_SIZE("committer "),
+				  &commit->committer, &commit->commit_time);
+		break;
+
 	default:
 		/* Fill in the commit title if it has not already been set. */
 		if (*commit->title)
@@ -657,7 +674,7 @@ static struct view_ops main_ops = {
 	view_column_grep,
 	main_select,
 	main_done,
-	view_column_bit(AUTHOR) | view_column_bit(COMMIT_TITLE) |
+	view_column_bit(AUTHOR) | view_column_bit(COMMITTER) | view_column_bit(COMMIT_TITLE) |
 		view_column_bit(DATE) |	view_column_bit(ID) |
 		view_column_bit(LINE_NUMBER),
 	main_get_column_data,
