@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2022 Jonas Fonseca <jonas.fonseca@gmail.com>
+/* Copyright (c) 2006-2025 Jonas Fonseca <jonas.fonseca@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,7 +26,9 @@
 
 struct reference {
 	const struct ident *author;	/* Author of the last commit. */
-	struct time time;		/* Date of the last activity. */
+	struct time author_time;	/* Date of the last activity. */
+	const struct ident *committer;	/* Last committer. */
+	struct time commit_time;	/* Date of the last activity. */
 	char title[128];		/* First line of the commit message. */
 	const struct ref *ref;		/* Name and commit ID information. */
 };
@@ -43,15 +45,21 @@ enum refs_filter {
 	REFS_FILTER_TAGS     = 1 << 0,
 	REFS_FILTER_BRANCHES = 1 << 1,
 	REFS_FILTER_REMOTES  = 1 << 2,
+	REFS_FILTER_ALL	     = 1 << 3,
 } refs_filter = REFS_FILTER_NONE;
 
 static bool
 refs_get_column_data(struct view *view, const struct line *line, struct view_column_data *column_data)
 {
 	const struct reference *reference = line->data;
+	struct view_column *column = get_view_column(view, VIEW_COLUMN_DATE);
+	bool use_author_date = column && column->opt.date.use_author;
 
 	column_data->author = reference->author;
-	column_data->date = &reference->time;
+	column_data->committer = reference->committer;
+	column_data->date = use_author_date
+				? &reference->author_time
+				: &reference->commit_time;
 	column_data->id = reference->ref->id;
 	column_data->ref = reference->ref;
 	column_data->commit_title = reference->title;
@@ -97,6 +105,7 @@ refs_read(struct view *view, struct buffer *buf, bool force_stop)
 {
 	struct reference template = {0};
 	char *author;
+	char *committer;
 	char *title;
 	size_t i;
 
@@ -107,10 +116,14 @@ refs_read(struct view *view, struct buffer *buf, bool force_stop)
 		return false;
 
 	author = io_memchr(buf, buf->data, 0);
-	title = io_memchr(buf, author, 0);
+	committer = io_memchr(buf, author, 0);
+	title = io_memchr(buf, committer, 0);
 
 	if (author)
-		parse_author_line(author, &template.author, &template.time);
+		parse_author_line(author, &template.author, &template.author_time);
+
+	if (committer)
+		parse_author_line(committer, &template.committer, &template.commit_time);
 
 	for (i = 0; i < view->lines; i++) {
 		struct reference *reference = view->line[i].data;
@@ -119,7 +132,9 @@ refs_read(struct view *view, struct buffer *buf, bool force_stop)
 			continue;
 
 		reference->author = template.author;
-		reference->time = template.time;
+		reference->author_time = template.author_time;
+		reference->committer = template.committer;
+		reference->commit_time = template.commit_time;
 
 		if (title)
 			string_expand(reference->title, sizeof(reference->title), title, strlen(title), 1);
@@ -137,9 +152,10 @@ refs_open_visitor(void *data, const struct ref *ref)
 	struct view *view = data;
 	struct reference *reference;
 	bool is_all = ref == refs_all;
+	const struct ref_format *fmt = get_ref_format(opt_reference_format, ref);
 	struct line *line;
 
-        if (!is_all)
+	if (!is_all)
 		switch (refs_filter) {
 		case REFS_FILTER_TAGS:
 			if (ref->type != REFERENCE_TAG && ref->type != REFERENCE_LOCAL_TAG)
@@ -154,6 +170,13 @@ refs_open_visitor(void *data, const struct ref *ref)
 				return true;
 			break;
 		case REFS_FILTER_NONE:
+			if (ref->type == REFERENCE_STASH ||
+			    ref->type == REFERENCE_NOTE ||
+			    ref->type == REFERENCE_PREFETCH ||
+			    (!strcmp(fmt->start, "hide:") && !*fmt->end))
+				return true;
+			break;
+		case REFS_FILTER_ALL:
 		default:
 			break;
 		}
@@ -175,9 +198,10 @@ refs_open(struct view *view, enum open_flags flags)
 {
 	const char *refs_log[] = {
 		"git", "log", encoding_arg, "--no-color", "--date=raw",
-			opt_mailmap ? "--pretty=format:%H%x00%aN <%aE> %ad%x00%s"
-				    : "--pretty=format:%H%x00%an <%ae> %ad%x00%s",
-			"--all", "--simplify-by-decoration", NULL
+			opt_mailmap ? "--pretty=format:%H%x00%aN <%aE> %ad%x00%cN <%cE> %cd%x00%s"
+				    : "--pretty=format:%H%x00%an <%ae> %ad%x00%cn <%ce> %cd%x00%s",
+			"--all", "--decorate-refs=", "--simplify-by-decoration",
+			NULL
 	};
 	enum status_code code;
 	const char *name = REFS_ALL_NAME;
@@ -198,6 +222,8 @@ refs_open(struct view *view, enum open_flags flags)
 		} else if (!strncmp(refs_argv[i], "--remotes", 9)) {
 			refs_filter = REFS_FILTER_REMOTES;
 			name = REFS_REMOTES_NAME;
+		} else if (!strncmp(refs_argv[i], "--all", 5)) {
+			refs_filter = REFS_FILTER_ALL;
 		}
 	}
 
@@ -241,12 +267,13 @@ refs_select(struct view *view, struct line *line)
 	string_copy_rev(view->env->head, reference->ref->id);
 	string_ncopy(view->env->ref, reference->ref->name, strlen(reference->ref->name));
 	ref_update_env(view->env, reference->ref, false);
+	view->env->blob[0] = 0;
 }
 
 static struct view_ops refs_ops = {
 	"reference",
 	argv_env.head,
-	VIEW_REFRESH | VIEW_SORTABLE,
+	VIEW_REFRESH | VIEW_SORTABLE | VIEW_LOG_LIKE,
 	0,
 	refs_open,
 	refs_read,
@@ -255,7 +282,7 @@ static struct view_ops refs_ops = {
 	view_column_grep,
 	refs_select,
 	NULL,
-	view_column_bit(AUTHOR) | view_column_bit(COMMIT_TITLE) |
+	view_column_bit(AUTHOR) | view_column_bit(COMMITTER) | view_column_bit(COMMIT_TITLE) |
 		view_column_bit(DATE) | view_column_bit(ID) |
 		view_column_bit(LINE_NUMBER) | view_column_bit(REF),
 	refs_get_column_data,
