@@ -766,6 +766,8 @@ split_view(struct view *prev, struct view *view)
 	if (view != prev && view_is_displayed(prev)) {
 		/* "Blur" the previous view. */
 		update_view_title(prev);
+		draw_view_line(prev, prev->pos.lineno - prev->pos.offset);
+		wnoutrefresh(prev->win);
 	}
 
 	if (view_has_flags(prev, VIEW_FLEX_WIDTH) && vsplit && nviews == 1)
@@ -930,6 +932,9 @@ compare_view_column(enum view_column_type column, bool use_file_mode,
 	case VIEW_COLUMN_AUTHOR:
 		return apply_comparator(ident_compare, column_data1->author, column_data2->author);
 
+	case VIEW_COLUMN_COMMITTER:
+		return apply_comparator(ident_compare, column_data1->committer, column_data2->committer);
+
 	case VIEW_COLUMN_DATE:
 		return apply_comparator(timecmp, column_data1->date, column_data2->date);
 
@@ -980,6 +985,7 @@ static enum view_column_type view_column_order[] = {
 	VIEW_COLUMN_FILE_SIZE,
 	VIEW_COLUMN_DATE,
 	VIEW_COLUMN_AUTHOR,
+	VIEW_COLUMN_COMMITTER,
 	VIEW_COLUMN_COMMIT_TITLE,
 	VIEW_COLUMN_LINE_NUMBER,
 	VIEW_COLUMN_SECTION,
@@ -1066,6 +1072,11 @@ view_column_text(struct view *view, struct view_column_data *column_data,
 			text = mkauthor(column_data->author, column->opt.author.width, column->opt.author.display);
 		break;
 
+	case VIEW_COLUMN_COMMITTER:
+		if (column_data->committer)
+			text = mkauthor(column_data->committer, column->opt.committer.width, column->opt.committer.display);
+		break;
+
 	case VIEW_COLUMN_COMMIT_TITLE:
 		text = column_data->commit_title;
 		break;
@@ -1520,6 +1531,11 @@ view_column_info_update(struct view *view, struct line *line)
 			maxwidth = MAXWIDTH(column->opt.author.maxwidth);
 			break;
 
+		case VIEW_COLUMN_COMMITTER:
+			width = column->opt.committer.width;
+			maxwidth = MAXWIDTH(column->opt.committer.maxwidth);
+			break;
+
 		case VIEW_COLUMN_COMMIT_TITLE:
 			break;
 
